@@ -1,4 +1,4 @@
-using TimeZones.TZData: _LATEST_FILE_PATH, read_latest
+using TimeZones.TZData: _latest_file_path, read_latest
 using TimeZones.TZData: tzdata_latest_version, tzdata_versions
 
 @testset "tzdata_versions" begin
@@ -12,8 +12,9 @@ end
 
     # Validate the contents of the latest file which will be automatically created when
     # downloading the latest data.
-    @test isfile(_LATEST_FILE_PATH[])
-    version, retrieved = read_latest(_LATEST_FILE_PATH[])
+    latest_file_path = _latest_file_path()
+    @test isfile(latest_file_path)
+    version, retrieved = read_latest(latest_file_path)
     @test occursin(r"\A(?:\d{2}){1,2}[a-z]?\z", version)
     @test isa(retrieved, DateTime)
 end
